# Examples

This folder contains three progressively more advanced drawing examples that
illustrate how to use `Canvas`, `Renderer`, and `DrawConfig` together.

## Files

- `1_hello_world.py`: minimal centered rectangle and text.
- `2_rotate_shift.py`: per-element rotation and translation without using matplotlib transform.
- `3_affine.py`: apply one shared affine transform for consistent rotation/shift or more complex transformations like scale.

## Output

Each script writes an SVG into `example/output/` with a matching filename.
